Discover Packages
github.com/dfanso/commit-msg
internal
claude
package
Version:
v1.6.1
Opens a new window with list of versions in this module.
Published: Oct 23, 2025
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
GenerateCommitMessage produces a commit summary using Anthropic's Claude API.
type ClaudeRequest struct {
Model string `json:"model"`
Messages []types .Message `json:"messages"`
MaxTokens int `json:"max_tokens"`
}
ClaudeRequest describes the payload sent to Anthropic's Claude messages API.
type ClaudeResponse struct {
ID string `json:"id"`
Type string `json:"type"`
Content []struct {
Type string `json:"type"`
Text string `json:"text"`
} `json:"content"`
}
ClaudeResponse captures the subset of fields used from Anthropic responses.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.