display

package
v1.7.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 29, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	MaxStagedFiles    = 5
	MaxUnstagedFiles  = 3
	MaxUntrackedFiles = 3
)

Variables

This section is empty.

Functions

func ShowChangesPreview

func ShowChangesPreview(stats *FileStatistics)

ShowChangesPreview displays a preview of changes with line statistics

func ShowCommitMessage

func ShowCommitMessage(message string)

ShowCommitMessage displays the commit message in a styled panel

func ShowFileStatistics

func ShowFileStatistics(stats *FileStatistics)

ShowFileStatistics displays file statistics with colored output

Types

type FileStatistics

type FileStatistics struct {
	StagedFiles    []string
	UnstagedFiles  []string
	UntrackedFiles []string
	TotalFiles     int
	LinesAdded     int
	LinesDeleted   int
}

FileStatistics holds statistics about changed files

Jump to