git

package
v1.3.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2025 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetChanges

func GetChanges(config *types.RepoConfig) (string, error)

GetChanges retrieves all Git changes including staged, unstaged, and untracked files

func IsRepository

func IsRepository(path string) bool

IsRepository checks if a directory is a git repository

Types

This section is empty.

Jump to