utils

package
v1.3.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FilterEmpty

func FilterEmpty(slice []string) []string

FilterEmpty removes empty strings from a slice

func IsSmallFile

func IsSmallFile(filename string) bool

IsSmallFile checks if a file is small enough to include in context

func IsTextFile

func IsTextFile(filename string) bool

IsTextFile checks if a file is likely to be a text file

func NormalizePath

func NormalizePath(path string) string

NormalizePath handles both forward and backslashes

Types

This section is empty.

Jump to