Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetChanges ¶
func GetChanges(config *types.RepoConfig) (string, error)
GetChanges retrieves all Git changes including staged, unstaged, and untracked files
func IsRepository ¶
IsRepository checks if a directory is a git repository
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.