Documentation
¶
Overview ¶
Copyright © 2025 NAME HERE <EMAIL ADDRESS>
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateCommitMsg ¶
CreateCommitMsg launches the interactive flow for reviewing, regenerating, editing, and accepting AI-generated commit messages in the current repo. If dryRun is true, it displays the prompt without making an API call.
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.