Discover Packages
github.com/dfanso/commit-msg
internal
claude
package
Version:
v1.3.5
Opens a new window with list of versions in this module.
Published: Oct 4, 2025
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type ClaudeRequest struct {
Model string `json:"model"`
Messages []Message `json:"messages"`
MaxTokens int `json:"max_tokens"`
}
type ClaudeResponse struct {
ID string `json:"id"`
Type string `json:"type"`
Content []struct {
Type string `json:"type"`
Text string `json:"text"`
} `json:"content"`
}
type Message struct {
Role string `json:"role"`
Content string `json:"content"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.