package
Version:
v1.3.21
Opens a new window with list of versions in this module.
Published: Oct 7, 2025
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type OllamaRequest struct {
Model string `json:"model"`
Prompt string `json:"prompt"`
}
type OllamaResponse struct {
Response string `json:"response"`
Done bool `json:"done"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.