Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetDetectedPatterns ¶
GetDetectedPatterns returns names of all detected sensitive patterns
func HasSensitiveData ¶
HasSensitiveData checks if the content contains any sensitive patterns
func ScrubEnvFile ¶
ScrubEnvFile specifically handles .env file patterns
func ScrubLines ¶
ScrubLines removes sensitive information line by line This is useful for more granular control
Types ¶
Click to show internal directories.
Click to hide internal directories.