Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FilterEmpty ¶
FilterEmpty removes empty strings from a slice
func IsSmallFile ¶
IsSmallFile checks if a file is small enough to include in context
func IsTextFile ¶
IsTextFile checks if a file is likely to be a text file
func NormalizePath ¶
NormalizePath handles both forward and backslashes
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.